@@ -1,8 +1,8 @@
 package Cassandra::Client::AsyncAnyEvent;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13_008'; # TRIAL
+$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13_009'; # TRIAL
 
-$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13008';use 5.010;
+$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13009';use 5.010;
 use strict;
 use warnings;
 
@@ -148,7 +148,7 @@ sub timer {
 
 sub later {
     my ($self, $callback)= @_;
-    AE::postpone($callback);
+    &AE::postpone($callback);
 }
 
 # $something->($async->wait(my $w)); my ($error, $result)= $w->();
@@ -183,7 +183,7 @@ Cassandra::Client::AsyncAnyEvent
 
 =head1 VERSION
 
-version 0.13_008
+version 0.13_009
 
 =head1 AUTHOR
 
